@@ -4,6 +4,7 @@
 from . import libswn as swn
 from .workday import *
 from .database import *
+from .msgc import *
 
 import datetime,time,inspect,collections,hashlib,base64,urllib.request,json,subprocess
 import os,re,shutil,smtplib,sys,getpass
@@ -458,6 +459,7 @@ stime=time.time()
 srvname=swenv("srvname","")
 srvpass=swenv("srvpass","")
 xx=c_xx()
+xxtz=c_xxtz()
 
 if __name__ == "__main__":
     start(globals(),"libsw3库")
